@@ -1,5 +1,5 @@
 /*
- * Based(V2.5) on amavis-milter.c,v 1.1.2.3.2.40 2003/06/06 12:34:58 lhecking Exp
+ * (V2.6) Based on amavis-milter.c,v 1.1.2.3.2.40 2003/06/06 12:34:58 lhecking Exp
  */
 
 /*
@@ -754,6 +754,7 @@ mlfi_eom(SMFICTX *ctx)
 				     sendmail_queueid, strerror(errno));
 	} else {
 	    /* get result from amavisd */
+	    memset(buff, 0, sizeof *buff);
 	    r = recv(sock, buff, 6, 0);
 	    amavis_syslog(DBG_DEBUG, "%s: (mlfi_eom) received %s from daemon", sendmail_queueid, buff);
 	    if (r < 0)
